#!/bin/bash

# Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of ubiquity-le
#
# ubiquity-le is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.


#------------------------------------------------------------------------------

MOUNTLIST="/var/lib/ubiquity/mountlist-uses-type"
export HOME=/root
export LC_ALL=C

touch $MOUNTLIST

removeMountList()
{
    grep -v "$1" $MOUNTLIST > $MOUNTLIST.tmp
    mv -f $MOUNTLIST.tmp $MOUNTLIST
}

checkMountedFS()
{
    for file in $(sort -r $MOUNTLIST); do
        if ! ( umount -l $file && removeMountList $file ); then
            $log "Error: While umounting $file"
            removeMountList $file
        fi
    done
}

initChroot()
{
    set +e
    checkMountedFS

    mount --bind /dev $ROOT/dev && echo "$ROOT/dev" >> $MOUNTLIST
    mount --bind /proc $ROOT/proc && echo "$ROOT/proc" >> $MOUNTLIST
    mount --bind /sys $ROOT/sys && echo "$ROOT/sys" >> $MOUNTLIST
    mount --bind /dev/pts $ROOT/dev/pts && echo "$ROOT/dev/pts" \
        >> $MOUNTLIST

    $chroot $ROOT dbus-uuidgen > "$ROOT/var/lib/dbus/machine-id"
    set -e
}

closeChroot()
{
    set +e

    rm -rf $ROOT/root/.bash_history $ROOT/var/lib/dbus/machine-id

    umount -l $ROOT/dev/pts && removeMountList $ROOT/dev/pts
    umount -l $ROOT/dev && removeMountList $ROOT/dev
    umount -l $ROOT/sys && removeMountList $ROOT/sys
    umount -l $ROOT/proc && removeMountList $ROOT/proc

    set -e
}
